require 'waskey'
require 'level'
require 'player'
require 'coin'
require 'block'
require 'stages'
require 'menu'
require 'credits'
require 'pause'
require 'settings'
require 'res'
require 'splash'

-- block definitions:
blocks = {
	brick = {
		solid = true,
		draw = block.draw,
		graphic = block.graphic.brick},
	dirt = {
		solid = true,
		draw = block.draw,
		graphic = block.graphic.dirt},
	grass = {
		solid = true,
		draw = block.draw,
		graphic = block.graphic.grass},
	lava = {
		deadly = true,
		graphic = block.graphic.lava,
		update = block.anim16.update,
		draw = block.anim16.draw,
		frame = 0,
		speed = 8},
	door = {
		win = true,
		draw = block.drawOffset,
		graphic = block.graphic.door,
		ofsX = -4, ofsY = -4},
}
-- rules for loading levels from string
level.rules = {
	{ ' ' },
	{ 'x', 0, blocks.brick },
	{ 'd', 0, blocks.dirt },
	{ 'g', 0, blocks.grass },
	{ 'l', 0, blocks.lava },
	{ 'w', 0, blocks.door },
	{ 'p', 1, player },
	{ 'c', 1, coin }
}

function love.load()
	
	font = love.graphics.newFont(12)
	
	love.graphics.setDefaultImageFilter( 'nearest', 'nearest' )
	if love.filesystem.exists('save.hssav') then
		load = {}
		for line in love.filesystem.lines('save.hssav') do
			table.insert(load, line)
		end
	else
		load = {}
		table.insert(load, 0)
		table.insert(load, 0)
		table.insert(load, 0)
		sf = love.filesystem.newFile('save.hssav')
		sf:open('w')
		sf:write('0\r\n0\r\n0')
	end

	love.graphics.setBackgroundColor(50, 50, 50)
	score = load[2]
	deaths = load[3]
	gamestate = 'menu'
	level.current = load[1]
	level.next()
end

function love.update(dt)
	if gamestate == 'game' then
		level.update(dt)
	elseif gamestate == 'menu' then
		menu.update()
	elseif gamestate == 'credits' then
		credits.update(dt)
	elseif gamestate == 'pause' then
		pause.update()
	elseif gamestate == 'settings' then
		settings.update()
	elseif gamestate == 'res' then
		res.update()
	elseif gamestate == 'splash' then
		splash.update(dt)
	end
	love.keyboard.updateKeys()
end

function love.draw()
	
	love.graphics.scale(level.scale)

	if gamestate == 'game' then
		level.draw()
	elseif gamestate == 'menu' then
		menu.draw()
	elseif gamestate == 'credits' then
		credits.draw()
	elseif gamestate == 'pause' then
		pause.draw()
	elseif gamestate == 'settings' then
		settings.draw()
	elseif gamestate == 'res' then
		res.draw()
	elseif gamestate == 'splash' then
		splash.draw()
	end
end